| nonregdist | R Documentation |
This function computes different measures of distance between prices of production (PP), market prices (MP) and direct prices (DP).
nonregdist(x, y, w, w_avg, Q)
x |
price of production vector (1 x n). |
y |
direct prices vector (1 x n). |
w |
vector of nominal wage rates (1 x n). |
w_avg |
average wage rate (scalar). |
Q |
gross output vector (1 x n) |
A list with the following elements:
rmseppmp |
RMSE between price of production and market prices |
rmsedpmp |
RMSE between direct prices and market prices |
rmseppdp |
RMSE between prices of production and direct prices |
madppmp |
MAD between price of production and market prices |
maddpmp |
MAD between direct prices and market prices |
madppdp |
MAD between prices of production and direct prices |
mawdppmp |
MAWD between price of production and market prices |
mawddpmp |
MAWD between direct prices and market prices |
mawdppdp |
MAWD between prices of production and direct prices |
angleppmp |
Angle between price of production and market prices |
angledpmp |
Angle between direct prices and market prices |
angleppdp |
Angle between prices of production and direct prices |
ddistppmp |
D-distance between price of production and market prices |
ddistdpmp |
D-distance between direct prices and market prices |
ddistppdp |
D-distance between prices of production and direct prices |
# ------ Data
# price of production vector
x<- matrix(
data = c(0.25, 0.50, 0.75),
nrow=1
)
# direct price vector
y <- matrix(
data = c(0.33, 0.275, 0.85),
ncol=1
)
# Gross output vector
Q <- matrix(
data = c(26530, 18168, 73840),
ncol=1
)
# nominal wage rate vector
w <- matrix(
data = c(0.5, 0.33, 0.75),
ncol=1
)
# average wage (scalar)
w_avg <- 0.66
# Compute prices of production
nonregdist(x = x, y = y, Q = Q, w = w, w_avg = w_avg)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.