ppnewint1: Circulating capital model using the New Interpretation.

View source: R/ppnewint1.R

ppnewint1R Documentation

Circulating capital model using the New Interpretation.

Description

This function computes the uniform rate of profit, prices of production and labor values for a basic circulating capital model using the New Interpretation.

Usage

ppnewint1(A, w, v, Q, l_simple)

Arguments

A

input-output matrix (n x n).

w

uniform nominal wage rate (scalar).

v

value of labor power (scalar)

Q

gross output vector (n x 1).

l_simple

vector of simple labor input (1 x n).

Value

A list with the following elements:

meig

Maximum eigen value of A

urop

Uniform rate of profit (as a fraction)

mrop

Maximum rate of profit (as a fraction)

pp

Price of production vector

dp

Direct prices

lvalues

Labor values vector

Anonneg

Is A Nonnegative? (1=Y,0=N)

Airred

Is A Irreducible? (1=Y,0=N)

Examples


# ------ Data
# Input-output matrix
A <- matrix(
data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165),
nrow=3, ncol=3, byrow = TRUE
)
# Direct labor input vector (complex)
l <- matrix(
data = c(0.193, 3.562, 0.616),
nrow=1
)
# Real wage bundle
b <- matrix(
data = c(0.0109, 0.0275, 0.296),
ncol=1
)
# Gross output vector
Q <- matrix(
data = c(26530, 18168, 73840),
ncol=1
)
# Direct labor input vector (simple)
l_simple <- l
# Market price vector
m <- matrix(data = c(4, 60, 7),nrow=1)
# Uniform nominal wage rate
wavg <- m%*%b
# Value of labor power
v <- 2/3
# Compute prices of production
ppnewint1(A = A,w = wavg[1,1],v=v,Q = Q,l_simple = l)


clptheory documentation built on March 18, 2026, 1:07 a.m.