ppstdint1: Circulating capital model using the Standard Interpretation.

View source: R/ppstdint1.R

ppstdint1R Documentation

Circulating capital model using the Standard Interpretation.

Description

This function computes the uniform rate of profit, prices of production and labor values for a basic circulating capital model using the Standard Interpretation.

Usage

ppstdint1(A, b, Q, l_simple)

Arguments

A

input-output matrix (n x n).

b

vector real wage bundle (n x 1).

Q

gross output vector (n x 1).

l_simple

vector of simple labor input (1 x n).

Value

A list with the following elements:

meig

Maximum eigen value of M

urop

Uniform rate of profit (as a fraction)

mrop

Maximum rate of profit (as a fraction)

pp

Price of production vector

dp

Direct prices

lvalues

Labor values vector

Mnonneg

Is M Nonnegative? (1=Y,0=N)

Mirred

Is M Irreducible? (1=Y,0=N)

Examples


# ------ Data
# Input-output matrix
A <- matrix(
data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165),
nrow=3, ncol=3, byrow = TRUE
)
# Direct labor input vector (complex)
l <- matrix(
data = c(0.193, 3.562, 0.616),
nrow=1
)
# Real wage bundle
b <- matrix(
data = c(0.0109, 0.0275, 0.296),
ncol=1
)
# Gross output vector
Q <- matrix(
data = c(26530, 18168, 73840),
ncol=1
)
# Direct labor input vector (simple)
l_simple <- l
# Compute prices of production
ppstdint1(A = A,b = b,Q = Q,l_simple = l)


clptheory documentation built on March 18, 2026, 1:07 a.m.