ppstdint2: Capital stock model using the Standard Interpretation.

View source: R/ppstdint2.R

ppstdint2R Documentation

Capital stock model using the Standard Interpretation.

Description

This function computes the uniform rate of profit, prices of production and labor values for a capital stock model using the Standard Interpretation.

Usage

ppstdint2(A, l, b, Q, D, K, t, Tax)

Arguments

A

input-output matrix (n x n).

l

vector of simple labor input (1 x n).

b

vector real wage bundle (n x 1).

Q

gross output vector (n x 1).

D

depreciation matrix (n x n).

K

capital stock coefficient matrix (n x n).

t

diagonal matrix of turnover rates (n x n).

Tax

matrix of tax rates (n x n).

Value

A list with the following elements:

meig

Maximum eigen value of M

urop

Uniform rate of profit (as a fraction)

mrop

Maximum rate of profit (as a fraction)

pp

Price of production vector

dp

Direct prices

lvalues

Labor values vector

Mnonneg

Is M Nonnegative? (1=Y,0=N)

Mirred

Is M Irreducible? (1=Y,0=N)

Examples


# ------ Data
# Input-output matrix
A <- matrix(
data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165),
nrow=3, ncol=3, byrow = TRUE
)
# Depreciation matrix
D <- matrix(
data = c(0,0,0,0.00568,0.0267,0.0028,0.00265,0.0147,0.00246),
nrow = 3, ncol = 3, byrow = TRUE
)
# Direct labor input vector (complex)
l <- matrix(
data = c(0.193, 3.562, 0.616),
nrow=1
)
# Real wage bundle
b <- matrix(
data = c(0.0109, 0.0275, 0.296),
ncol=1
)
# Gross output vector
Q <- matrix(
data = c(26530, 18168, 73840),
ncol=1
)
# Gross output vector 
Q <- matrix(
data = c(26530, 18168, 73840),
ncol = 1
)
# Capital stock coefficient matrix
K <- matrix(
data = c(0,0,0,0.120,0.791,0.096,0.037,0.251,0.043),
nrow=3, ncol=3, byrow=TRUE
)
# Diagonal matrix of turnover rates
t <- diag(c(0.317, 0.099, 0.187))
# Matrix of tax rates (assumed 0)
Tax <- matrix(0,nrow=3,ncol=3)

# Compute prices of production
ppstdint2(A=A,l=l,b=b,Q=Q,D=D,K=K,t=t,Tax=Tax)

clptheory documentation built on March 18, 2026, 1:07 a.m.