Learn R Programming

clptheory (version 0.1.0)

usarwb: Real Wage Bundle, USA

Description

Personal Consumption Expenditure from the Input Output Table for the USA. This data is used to construct the real wage bundle for computing the price of production vector.

Usage

usarwb

Arguments

Format

Consumption expenditure on the output of 53 industries for USA for 15 years, 2000-2014.

Examples

Run this code
data(usarwb)

Run the code above in your browser using DataLab