| ppsraffa1 | R Documentation |
This function computes the uniform rate of profit, prices of production and labor values for a basic circulating capital model using the Sraffian method.
ppsraffa1(A, Q, pshare, l_simple)
A |
input-output matrix (n x n). |
Q |
gross output vector (n x 1). |
pshare |
profit share (scalar) |
l_simple |
vector of simple labor input (1 x n). |
A list with the following elements:
meig |
Maximum eigen value of A |
urop |
Uniform rate of profit (as a fraction) |
mrop |
Maximum rate of profit (as a fraction) |
ppabs |
Price of production vector (absolute) |
pprel |
Price of production vector (relative) |
lvalues |
Labor values vector |
mevn |
Monetary expression of value using net output |
mevg |
Monetary expression of value using gross output |
Anonneg |
Is A Nonnegative? (1=Y,0=N) |
Airred |
Is A Irreducible? (1=Y,0=N) |
# ------ Data
# Input-output matrix
A <- matrix(
data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165),
nrow=3, ncol=3, byrow = TRUE
)
# Direct labor input vector (complex)
l <- matrix(
data = c(0.193, 3.562, 0.616),
nrow=1
)
# Gross output vector
Q <- matrix(
data = c(26530, 18168, 73840),
ncol=1
)
# Direct labor input vector (simple)
l_simple <- l
# Profit share
pshare <- 1/3
# Compute prices of production
ppsraffa1(A = A,pshare=pshare,Q = Q,l_simple = l)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.